summaryrefslogtreecommitdiff
path: root/firmware/2lib/include/2misc.h
diff options
context:
space:
mode:
authorYu-Ping Wu <yupingso@chromium.org>2020-06-10 17:25:15 +0800
committerCommit Bot <commit-bot@chromium.org>2020-06-13 08:51:23 +0000
commit7f6c50e7cc531784f29ef4018b34924083fc902c (patch)
tree652a17e45e15ae1bd664ddef75fed36cf54770fa /firmware/2lib/include/2misc.h
parent5cd75be8d1e908adbf73edf04c903539864efab0 (diff)
downloadvboot-7f6c50e7cc531784f29ef4018b34924083fc902c.tar.gz
vboot: rename USB to more accurate EXTERNAL
Rename enumerators of the vb2_dev_default_boot_target enum as follows, because the term USB is not quite accurate (we can also boot from an SD card). VB2_DEV_DEFAULT_BOOT_TARGET_DISK --> VB2_DEV_DEFAULT_BOOT_TARGET_INTERNAL VB2_DEV_DEFAULT_BOOT_TARGET_USB --> VB2_DEV_DEFAULT_BOOT_TARGET_EXTERNAL Also perform similar renaming for the following. enum vb2_nv_param: VB2_NV_DEV_BOOT_USB --> VB2_NV_DEV_BOOT_EXTERNAL enum vb2_secdata_fwmp_flags: VB2_SECDATA_FWMP_DEV_ENABLE_USB --> VB2_SECDATA_FWMP_DEV_ENABLE_EXTERNAL constants: VB2_NV_DEV_FLAG_USB --> VB2_NV_DEV_FLAG_EXTERNAL functions: vb2_dev_boot_usb_allowed --> vb2_dev_boot_external_allowed BRANCH=none BUG=none TEST=make runtests Change-Id: Iad16fcf34d76da08c6d8a81e150c7fde927c743b Signed-off-by: Yu-Ping Wu <yupingso@chromium.org> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/vboot_reference/+/2237622 Reviewed-by: Joel Kitching <kitching@chromium.org>
Diffstat (limited to 'firmware/2lib/include/2misc.h')
-rw-r--r--firmware/2lib/include/2misc.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/firmware/2lib/include/2misc.h b/firmware/2lib/include/2misc.h
index 2916b236..334b1485 100644
--- a/firmware/2lib/include/2misc.h
+++ b/firmware/2lib/include/2misc.h
@@ -223,7 +223,7 @@ int vb2_dev_boot_allowed(struct vb2_context *ctx);
/**
* Determine if booting from legacy BIOS is allowed.
*
- * Legacy BIOS is allowed if one of the legacy-related flags is set:
+ * Legacy BIOS is allowed if any of these flags are set:
* VB2_NV_DEV_BOOT_LEGACY, VB2_GBB_FLAG_FORCE_DEV_BOOT_LEGACY, and
* VB2_SECDATA_FWMP_DEV_ENABLE_LEGACY.
*
@@ -233,15 +233,15 @@ int vb2_dev_boot_allowed(struct vb2_context *ctx);
int vb2_dev_boot_legacy_allowed(struct vb2_context *ctx);
/**
* Determine if booting from USB or SD card is allowed.
*
* Booting from USB is allowed if one of the USB-related flags is set:
* VB2_NV_DEV_BOOT_USB, VB2_GBB_FLAG_FORCE_DEV_BOOT_USB, and
* VB2_SECDATA_FWMP_DEV_ENABLE_USB.
*
* @param ctx Vboot context
* @return 1 if allowed, or 0 otherwise.
*/
-int vb2_dev_boot_usb_allowed(struct vb2_context *ctx);
+int vb2_dev_boot_external_allowed(struct vb2_context *ctx);
#endif /* VBOOT_REFERENCE_2MISC_H_ */
@@ -233,15 +233,15 @@ int vb2_dev_boot_allowed(struct vb2_context *ctx);
int vb2_dev_boot_legacy_allowed(struct vb2_context *ctx);
/**
- * Determine if booting from USB or SD card is allowed.
+ * Determine if booting from external disk is allowed.
*
@@ -233,15 +233,15 @@ int vb2_dev_boot_allowed(struct vb2_context *ctx);
*
- * Booting from USB is allowed if one of the USB-related flags is set:
- * VB2_NV_DEV_BOOT_USB, VB2_GBB_FLAG_FORCE_DEV_BOOT_USB, and
- * VB2_SECDATA_FWMP_DEV_ENABLE_USB.
+ * Booting from external disk is allowed if any of these flags are set:
+ * VB2_NV_DEV_BOOT_EXTERNAL, VB2_GBB_FLAG_FORCE_DEV_BOOT_USB, and
+ * VB2_SECDATA_FWMP_DEV_ENABLE_EXTERNAL.
*
* @param ctx Vboot context